function PS = HVspectrogram(img,radius)
    %Plots average Power Spectrum of linear img in H and V direction,
    %smoothed with pillbox (radius default 2px, zero = no filter).
    %By Jack Hogan, inspired by DSPographer. Nov 2019 Ver 0.26
    %https://www.strollswithmydog.com/hv-spectrogram/

    if nargin < 2
        radius = 2; end
        
    img = double(img) - mean2(img);     %make img mean = 0;
        
    PS = abs(fft2(img)).^2;             %Power Spectrum
    PS = PS / mean2(PS);                %Normalized so that mean2(PS) = 1, Plancherel
    if radius
        PS = imfilter(PS,fspecial('disk',radius),'symmetric'); end
    
    H = mean(PS,1);                     %mean PS in H dir by freq
    V = mean(PS,2);                     %mean PS in V dir by freq
    
    [M,N] = size(img);                  %plot to Nyquist in c/p
    figure;  plot( (0:ceil(N/2+1))/N , log2(H( 1+(0:ceil(N/2+1)) )) )
    hold on; plot( (0:ceil(M/2+1))/M , log2(V( 1+(0:ceil(M/2+1)) )) )
    grid on; grid minor; xlim([-0.01 0.51])
    xlabel('c/p'); ylabel('Average Energy Spectrum (stops)')
    legend('Horizontal','Vertical');
    title('Resultant Energy Spectrum in H and V directions')
end
